(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10178,        338]*)
(*NotebookOutlinePosition[     10823,        360]*)
(*  CellTagsIndexPosition[     10779,        356]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: DAR(",
  StyleBox["p",
    FontSlant->"Italic"],
  ")-Prozess"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Der Parameter \[Rho] des DAR(",
  StyleBox["p",
    FontSlant->"Italic"],
  ")-Prozesses aus Gleichung (4.16) gibt die Wahrscheinlichkeit an, dass das \
Symbol ",
  Cell[BoxData[
      \(TraditionalForm\`X\_n\)]],
  " aus den vorausgegangenen Symbolen der Sequenz gew\[ADoubleDot]hlt wird. \
Indem wir diesem Parameter den Wert 0.6 zuweisen, ist die Wahrscheinlichkeit \
f\[UDoubleDot]r einen R\[UDoubleDot]ckgriff innerhalb der Sequenz also auf \
60% gesetzt."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(\[Rho] = 0.6;\)\)], "Input"],

Cell[TextData[{
  "Durch die Festlegung der Markov-Ordnung (hier ",
  StyleBox["p",
    FontSlant->"Italic"],
  " = 6) wird die Dimension des Parametervektors \[Alpha] festgelegt. Der \
Vektor \[Alpha], dessen Komponenten wir hier von Hand vorgeben, beschreibt \
die St\[ADoubleDot]rke der Korrelation im Abstand ",
  StyleBox["k",
    FontSlant->"Italic"],
  "."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(p = 6;\)\)], "Input"],

Cell[BoxData[
    \(\(vecAlpha = {{1, 2, 3, 4, 5, 6}, {0.5, 0.1, 0.1, 0.1, 0.1, 
            0.1}};\)\)], "Input"],

Cell["\<\
Wir w\[ADoubleDot]hlen eine Verteilung bei der die Wahrscheinlichkeit, eine \
Eins als R\[UDoubleDot]ckgriffweite zu erhalten, 50% betr\[ADoubleDot]gt. Die \
verbleibenden f\[UDoubleDot]nf Werte 2, . . . , 6 werden mit der gleichen \
Wahrscheinlichkeit 1/10 angenommen. Die Summe der Wahrscheinlichkeiten muss \
aus Normierungsgr\[UDoubleDot]nden Eins ergeben.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[vecAlpha]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "2", "3", "4", "5", "6"},
          {"0.5`", "0.1`", "0.1`", "0.1`", "0.1`", "0.1`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ vecAlpha[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(0.9999999999999999`\)], "Output"]
}, Open  ]],

Cell["\<\
Auch die Verteilung der unabh\[ADoubleDot]ngig voneinander gezogenen Symbole, \
also des zuf\[ADoubleDot]lligen Sequenzbeitrags muss spezifiziert werden. \
Hier w\[ADoubleDot]hlen wir eine Gleichverteilung.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(distY = {{"\<A\>", "\<G\>", "\<C\>", "\<T\>"}, {0.25, 0.25, 0.25, 
            0.25}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[distY]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"A\"\>", "\<\"G\"\>", "\<\"C\"\>", "\<\"T\"\>"},
          {"0.25`", "0.25`", "0.25`", "0.25`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Das folgende Modul liefert eine ganze Zahl zwischen 1 und der Ordnung ",
  StyleBox["p",
    FontSlant->"Italic"],
  " des Prozesses als Funktionswert. Das Argument ist der Parametervektor \
\[Alpha]. Dabei nutzen wir das Prinzip der Zerlegung der Einheit, das wir \
schon in dem ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs in Kapitel 2.2 kennen gelernt haben. Dieser Befehl ist damit eine \
Realisierung der Zufallsvariablen ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " aus Gleichung (4.16)."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(A[vec_] := 
        Module[{tmp1, tmp2}, \[IndentingNewLine]tmp1 = 
            Random[]; \[IndentingNewLine]tmp2 = 
            FoldList[Plus, 0, 
              vec[\([2]\)]]; \[IndentingNewLine]\ \(Position[
                Sort[Append[tmp2, tmp1]], tmp1]\)[\([1, 1]\)] - 
            1\ \[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A[vecAlpha]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In \[ADoubleDot]hnlicher Weise definieren wir eine Funktion, die ein zuf\
\[ADoubleDot]lliges Symbol ausgibt. Hier ist der Funktionswert jedoch ein \
explizites Symbol und keine Zahl, die angibt, auf welches bereits vorliegende \
Symbol zur\[UDoubleDot]ckgegriffen wird. Diese Gr\[ODoubleDot]\[SZ]e stellt \
die Zufallsvariable ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_n\)]],
  " in Gleichung (4.20) dar."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(Y[dist_] := 
        Module[{tmp1, tmp2, tmp3}, \[IndentingNewLine]tmp1 = 
            Random[]; \[IndentingNewLine]tmp2 = 
            FoldList[Plus, 0, 
              dist[\([2]\)]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(If[
                tmp2[\([i]\)] \[LessEqual] tmp1 < tmp2[\([i + 1]\)], 
                tmp3 = dist[\([1, i]\)]];\), \[IndentingNewLine]{i, 1, 
              Length[tmp2] - 
                1}]; \[IndentingNewLine]tmp3\[IndentingNewLine]];\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Y[distY]\)], "Input"],

Cell[BoxData[
    \("G"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Um den Prozess zu initialisieren, m\[UDoubleDot]ssen nun genau ",
  StyleBox["p",
    FontSlant->"Italic"],
  " Symbole festgelegt werden. Erst dann kann die Rekursion begonnen werden. \
Diese ",
  StyleBox["p",
    FontSlant->"Italic"],
  " Werte sind ",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  " bis ",
  Cell[BoxData[
      \(TraditionalForm\`X\_p\)]],
  ". Sie werden zuf\[ADoubleDot]llig nach der Verteilung von Y gezogen."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(SeedRandom[1];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[X[n] = Y[distY], {n, 1, p}]\)], "Input"],

Cell[BoxData[
    \({"C", "T", "T", "A", "T", "C"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die eigentliche Rekursion besteht nun im Aufruf der einzelnen oben \
beschriebenen Funktionen. F\[UDoubleDot]r den Fall, dass eine gezogene \
Zufallszahl kleiner ist als der Parameter \[Rho], wird ",
  Cell[BoxData[
      \(TraditionalForm\`X\_n\)]],
  " durch einen R\[UDoubleDot]ckgriff in der Sequenz bestimmt. Dabei liefert \
die Funktion ",
  StyleBox["A",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " gerade die Anzahl von Schritten, die zur\[UDoubleDot]ckgegangen wird."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\[IndentingNewLine]If[Random[] < \[Rho], 
        X[n] = X[\ n - A[vecAlpha]], X[n] = Y[distY]], \[IndentingNewLine]{n, 
        p + 1, 100}]\)], "Input"],

Cell[BoxData[
    \({"T", "C", "T", "A", "C", "A", "T", "G", "G", "G", "A", "T", "T", "T", 
      "T", "A", "T", "T", "T", "C", "T", "T", "T", "T", "T", "T", "T", "T", 
      "A", "A", "A", "C", "C", "C", "C", "A", "A", "C", "A", "A", "A", "C", 
      "C", "C", "C", "C", "T", "T", "C", "T", "C", "C", "T", "C", "C", "C", 
      "C", "T", "T", "T", "C", "A", "A", "T", "T", "T", "T", "C", "C", "T", 
      "A", "C", "C", "A", "A", "C", "A", "C", "C", "A", "C", "C", "C", "C", 
      "C", "T", "T", "T", "T", "T", "T", "T", "A", "G"}\)], "Output"]
}, Open  ]],

Cell["\<\
Mit Hilfe z.B. der Transinformation kann nun die Markov-Eigenschaft einer \
solchen Sequenz sichtbar gemacht werden, so wie wir es im Verlauf des \
Kapitels diskutiert haben.
\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{507, 600},
WindowMargins->{{64, Automatic}, {Automatic, 41}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 213, 8, 68, "Subtitle"],
Cell[2548, 86, 541, 14, 109, "Text"],
Cell[3092, 102, 50, 1, 30, "Input"],
Cell[3145, 105, 424, 12, 90, "Text"],
Cell[3572, 119, 43, 1, 30, "Input"],
Cell[3618, 122, 114, 2, 50, "Input"],
Cell[3735, 126, 433, 8, 109, "Text"],

Cell[CellGroupData[{
Cell[4193, 138, 52, 1, 30, "Input"],
Cell[4248, 141, 341, 10, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4626, 156, 58, 1, 30, "Input"],
Cell[4687, 159, 53, 1, 29, "Output"]
}, Open  ]],
Cell[4755, 163, 279, 6, 71, "Text"],
Cell[5037, 171, 123, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[5185, 177, 49, 1, 30, "Input"],
Cell[5237, 180, 351, 10, 55, "Output"]
}, Open  ]],
Cell[5603, 193, 608, 16, 128, "Text"],
Cell[6214, 211, 348, 7, 110, "Input"],

Cell[CellGroupData[{
Cell[6587, 222, 44, 1, 30, "Input"],
Cell[6634, 225, 35, 1, 29, "Output"]
}, Open  ]],
Cell[6684, 229, 491, 11, 90, "Text"],
Cell[7178, 242, 508, 10, 190, "Input"],

Cell[CellGroupData[{
Cell[7711, 256, 41, 1, 30, "Input"],
Cell[7755, 259, 37, 1, 29, "Output"]
}, Open  ]],
Cell[7807, 263, 521, 17, 71, "Text"],
Cell[8331, 282, 51, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[8407, 287, 66, 1, 30, "Input"],
Cell[8476, 290, 64, 1, 29, "Output"]
}, Open  ]],
Cell[8555, 294, 590, 15, 110, "Text"],

Cell[CellGroupData[{
Cell[9170, 313, 180, 3, 90, "Input"],
Cell[9353, 318, 546, 7, 105, "Output"]
}, Open  ]],
Cell[9914, 328, 248, 7, 90, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

